@@ -253,7 +253,7 @@ DisplayCurrentPlayer(void) {
     if (players[CurrentPlayer].comp) {
       say (_("Computer playing for %s"), players[CurrentPlayer].name);
     } else {
-      say (_("%s! -- You're up."), players[CurrentPlayer].name);
+      say (_("%s! – You’re up."), players[CurrentPlayer].name);
     }
   }
 }
@@ -715,6 +715,7 @@ GyahtzeeCreateMainWindow (void)
   GtkWidget *toolbar;
   GtkWidget *tmp;
   GtkWidget *dicebox;
+  GtkWidget *undo_button;
   GMenu *app_menu, *section;
   int i, j;
 
@@ -740,7 +741,6 @@ GyahtzeeCreateMainWindow (void)
   section = g_menu_new ();
   g_menu_append_section (app_menu, NULL, G_MENU_MODEL (section));
   g_menu_append (section, _("_New Game"), "app.new-game");
-  g_menu_append (section, _("_Undo Move"), "app.undo");
   g_menu_append (section, _("_Preferences"), "app.preferences");
   g_menu_append (section, _("_Scores"), "app.scores");
   section = g_menu_new ();
@@ -760,6 +760,16 @@ GyahtzeeCreateMainWindow (void)
   gtk_widget_show (hbar);
   gtk_window_set_titlebar (GTK_WINDOW (window), hbar);
 
+  if (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL)
+    undo_button = gtk_button_new_from_icon_name ("edit-undo-rtl-symbolic", GTK_ICON_SIZE_BUTTON);
+  else
+    undo_button = gtk_button_new_from_icon_name ("edit-undo-symbolic", GTK_ICON_SIZE_BUTTON);
+  gtk_widget_set_valign (undo_button, GTK_ALIGN_CENTER);
+  gtk_actionable_set_action_name (GTK_ACTIONABLE (undo_button), "app.undo");
+  gtk_widget_set_tooltip_text (undo_button, _("Undo your most recent move"));
+  gtk_widget_show (undo_button);
+  gtk_header_bar_pack_start (GTK_HEADER_BAR (hbar), undo_button);
+
 	/*---- Content ----*/
 
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
@@ -846,12 +856,6 @@ main (int argc, char *argv[])
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  /*
-   * Required because the binary doesn't match the desktop file.
-   * Has to be before the call to g_option_context_parse.
-   */
-  g_set_prgname ("gtali");
-
   application = gtk_application_new ("org.gnome.tali", 0);
   g_signal_connect (application, "activate", G_CALLBACK (GyahtzeeCreateMainWindow), NULL);
 
@@ -917,7 +921,7 @@ main (int argc, char *argv[])
       exit(0);
   }
 
-  highscores = games_scores_new ("gtali",
+  highscores = games_scores_new ("tali",
                                  category_array, G_N_ELEMENTS (category_array),
                                  "game type", NULL,
                                  0 /* default category */,
